@@ -1,4 +1,4 @@
-# Copyright 2023 The Orbax Authors.
+# Copyright 2024 The Orbax Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,8 +14,10 @@
 
 """Shorthand for `Checkpointer(PyTreeCheckpointHandler())`."""
 
+from typing import Optional
 from orbax.checkpoint import checkpointer
-from orbax.checkpoint import pytree_checkpoint_handler
+from orbax.checkpoint import options as options_lib
+from orbax.checkpoint._src.handlers import pytree_checkpoint_handler
 
 
 class PyTreeCheckpointer(checkpointer.Checkpointer):
@@ -30,7 +32,7 @@ class PyTreeCheckpointer(checkpointer.Checkpointer):
 
   def __init__(
       self,
-      primary_host: int = 0,
+      primary_host: Optional[int] = 0,
       use_ocdbt: bool = True,
       use_zarr3=False,
   ):
@@ -38,5 +40,7 @@ class PyTreeCheckpointer(checkpointer.Checkpointer):
         pytree_checkpoint_handler.PyTreeCheckpointHandler(
             use_ocdbt=use_ocdbt, use_zarr3=use_zarr3
         ),
-        primary_host=primary_host,
+        multiprocessing_options=options_lib.MultiprocessingOptions(
+            primary_host=primary_host
+        ),
     )
